Package: DeMixT
Title: Cell type-specific deconvolution of heterogeneous tumor samples
        with two or three components using expression data from RNAseq
        or microarray platforms
Version: 2.0.0
Date: 2026-03-20
Authors@R: c(
    person("Zeya", "Wang", email = "zw17.rice@gmail.com", role = c("aut")),
    person("Shaolong", "Cao", email = "scao@mdanderson.org", role = c("aut")),
    person("Liyang", "Xie", email = "xieliyang@utexas.edu", role = c("aut")),
    person("Ruonan", "Li", email = "RLi10@mdanderson.org", role = c("cre")),
    person("Wenyi", "Wang", email = "wwang7@mdanderson.org", role = c("aut"))
    )
Description: DeMixT is a software package that performs deconvolution on transcriptome 
             data from a mixture of two or three components.
LazyData: TRUE
Depends: R (>= 4.0.0), parallel, Rcpp (>= 1.0.0), SummarizedExperiment
Imports: matrixStats, stats, truncdist, base64enc, ggplot2, KernSmooth,
        matrixcalc, sva, dendextend, fitdistrplus, pbapply, psych,
        magrittr, graphics, grDevices, S4Vectors
Suggests: knitr, rmarkdown, calibrate, BiocStyle
LinkingTo: Rcpp
NeedsCompilation: yes
VignetteBuilder: knitr
biocViews: Software, StatisticalMethod, Classification, GeneExpression,
        Sequencing, Microarray, TissueMicroarray, Coverage
License: GPL-3
RoxygenNote: 7.3.3
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/DeMixT
git_branch: RELEASE_3_23
git_last_commit: e3cf679
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Packaged: 2026-04-28 21:56:28 UTC; biocbuild
Author: Zeya Wang [aut],
  Shaolong Cao [aut],
  Liyang Xie [aut],
  Ruonan Li [cre],
  Wenyi Wang [aut]
Maintainer: Ruonan Li <RLi10@mdanderson.org>
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-29 04:40:07 UTC; unix
