useDynLib(DeMixT, .registration = TRUE)
export(DeMixT)
export(DeMixT_DE)
export(DeMixT_S2)
export(DeMixT_GS)
export(DeMixNB)
export(DeMixNB_preprocessing)
export(gene_selection_DE)
export(detect_suspicious_sample_by_hierarchical_clustering_2comp)
export(plot_sd)
export(subset_sd)
export(subset_sd_gene_remaining)
export(plot_dim)
export(scale_normalization_75th_percentile)
export(DeMixT_preprocessing)
export(batch_correction)
export(simulate_2comp)
export(simulate_3comp)
export(Optimum_KernelC)
import(KernSmooth) 
import(matrixcalc)
import(SummarizedExperiment)
import(parallel)
import(magrittr)
import(S4Vectors)
import(Rcpp)
import(base64enc)
importFrom(ggplot2, ggplot, aes, geom_point)
importFrom(psych, describe)
importFrom(dendextend, set)
importFrom(sva, ComBat)
importFrom(fitdistrplus, fitdist)
importFrom(pbapply, pblapply, pboptions)
importFrom(truncdist, rtrunc)
importFrom("matrixStats", "rowSds")
importFrom(Rcpp, evalCpp)
importFrom("grDevices", "rainbow")
importFrom("graphics", "abline", "legend", "par", "points", "segments")
importFrom("stats", "as.dendrogram", "cutree", "dist", "dnbinom", "hclust", 
"median", "optim", "prcomp", "qchisq", "rnbinom", "wilcox.test",
"IQR", "quantile", "rnorm", "runif", "rbinom")
importFrom(dendextend, rect.dendrogram)
